(_examples)=
# Examples

[Nadir Backscatter Ozone Retrieval](nadir_ozone)
: Setting up a Nadir Backscatter Ozone Retrieval using simulated measurements

[Limb Scatter Ozone Retrieval](limb_ozone)
: A limb scatter ozone retrieval

[Limb Scatter Aerosol Retrieval](limb_aerosol)
: A limb scatter aerosol retrieval

[Limb Scatter Polarized Aerosol Retrieval](limb_polarized_aerosol)
: A limb scatter aerosol retrieval using polarized measurements and a spectrally varying albedo

[A Synergistic Limb Scatter and Nadir Ozone Retrieval](synergy)
: Combining multiple observations for synergistic retrievals

```{toctree}
:maxdepth: 4
:hidden:

nadir_ozone
limb_ozone
limb_aerosol
limb_polarized_aerosol
synergy

```
